@@ -46,28 +46,94 @@
 #
 # ***** END LICENSE BLOCK *****
 
-class AMQPError(Exception): pass
 
-class AMQPConnectionError(AMQPError): pass
-class LoginError(AMQPConnectionError): pass
-class NoFreeChannels(AMQPConnectionError): pass
-class ContentTransmissionForbidden(AMQPConnectionError): pass
-class ConnectionClosed(AMQPConnectionError): pass
+class AMQPError(Exception):
+    pass
 
 
-class AMQPChannelError(AMQPError): pass
-class DuplicateConsumerTag(AMQPChannelError): pass
-class UnknownConsumerTag(AMQPChannelError): pass
-class ChannelClosed(AMQPChannelError): pass
+class AMQPConnectionError(AMQPError):
+    pass
 
 
-class RecursiveOperationDetected(AMQPError): pass
+class LoginError(AMQPConnectionError):
+    pass
 
 
-class ProtocolSyntaxError(AMQPError): pass
-class UnexpectedFrameError(ProtocolSyntaxError): pass
-class ProtocolVersionMismatch(ProtocolSyntaxError): pass
-class BodyTooLongError(ProtocolSyntaxError): pass
-class InvalidFrameError(ProtocolSyntaxError): pass
-class InvalidProtocolHeader(ProtocolSyntaxError): pass
-class InvalidTableError(ProtocolSyntaxError): pass
+class NoFreeChannels(AMQPConnectionError):
+    pass
+
+
+class ConnectionClosed(AMQPConnectionError):
+    pass
+
+
+class AMQPChannelError(AMQPError):
+    pass
+
+
+class ChannelBlocked(AMQPChannelError):
+    pass
+
+
+class DuplicateConsumerTag(AMQPChannelError):
+    pass
+
+
+class UnknownConsumerTag(AMQPChannelError):
+    pass
+
+
+class ChannelClosed(AMQPChannelError):
+    pass
+
+
+class InvalidChannelNumber(AMQPError):
+    pass
+
+
+class RecursiveOperationDetected(AMQPError):
+    pass
+
+
+class ProtocolSyntaxError(AMQPError):
+    pass
+
+
+class UnexpectedFrameError(ProtocolSyntaxError):
+    pass
+
+
+class ProtocolVersionMismatch(ProtocolSyntaxError):
+    pass
+
+
+class BodyTooLongError(ProtocolSyntaxError):
+    pass
+
+
+class InvalidFrameError(ProtocolSyntaxError):
+    pass
+
+
+class InvalidProtocolHeader(ProtocolSyntaxError):
+    pass
+
+
+class InvalidTableError(ProtocolSyntaxError):
+    pass
+
+
+class TableDecodingError(ProtocolSyntaxError):
+    pass
+
+
+class MethodNotImplemented(AMQPError):
+    pass
+
+
+class ChannelTransportError(Exception):
+    pass
+
+
+class CallbackReplyAlreadyRegistered(ChannelTransportError):
+    pass
